@@ -20,8 +20,8 @@
 #include <microfeed-common/microfeedprotocol.h>
 
 void do_authentication(MicrofeedPublisher* publisher, MicrofeedHttp* http) {
-	char* login;
-	char* password;
+	char* login = NULL;
+	char* password = NULL;
 	char* auth;
 
 	if ((login = microfeed_publisher_get_setting_value(publisher, "authentication.login", NULL)) &&
@@ -30,6 +30,8 @@ void do_authentication(MicrofeedPublisher* publisher, MicrofeedHttp* http) {
 		microfeed_http_set_basic_authentication(http, auth);
 		free(auth);
 	}
+	free(login);
+	free(password);
 }
 
 MicrofeedError* check_if_error(MicrofeedJson* json) {
