@@ -220,11 +220,11 @@ static MicrofeedItem* contact_to_item(Contact* contact) {
 	MicrofeedItem* item;
 	char* s;
 	
-	item = microfeed_item_new(contact->nick, time(NULL));
+	item = microfeed_item_new_with_status(contact->nick, time(NULL), MICROFEED_ITEM_STATUS_NEW);
 	microfeed_item_set_property(item, MICROFEED_ITEM_PROPERTY_NAME_USER_NICK, contact->nick);
 	microfeed_item_set_property(item, ".twitter.id", contact->id);
 	s = microfeed_util_string_concatenate(MICROFEED_FEED_URI_USER_PREFIX, contact->id, NULL);
-	microfeed_item_set_property(item, MICROFEED_ITEM_PROPERTY_NAME_USER_URI, s);
+	microfeed_item_set_property(item, MICROFEED_ITEM_PROPERTY_NAME_USER_FEED, s);
 	microfeed_memory_free(s);
 	if (contact->name) {
 		microfeed_item_set_property(item, MICROFEED_ITEM_PROPERTY_NAME_USER_NAME, contact->name);
